Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ProveUL ¶
ProveUL method is used to produce the ZKRP proof that secret x belongs to the interval [0,U^L].
func SetupUL ¶
SetupUL generates the signature for the interval [0,u^l). The value of u should be roughly b/log(b), but we can choose smaller values in order to get smaller parameters, at the cost of having worse performance.
Types ¶
type ParamsSet ¶
paramsSet contains elements generated by the verifier, which are necessary for the prover. This must be computed in a trusted setup.
Click to show internal directories.
Click to hide internal directories.